@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Liviu Lalescu <liviu@lalescu.ro>, (C) 2004
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2004
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -20,6 +20,7 @@
 #include <qstringlist.h>
 
 class Equipment;
+class Rules;
 
 class EquipmentsList: public QPtrList<Equipment>
 {
@@ -37,9 +38,10 @@ public:
 	Equipment();
 	~Equipment();
 
+	QString getXmlDescription();
 	QString getDescription();
 	QString getDetailedDescription();
-	QString getXMLDescription();
+	QString getDetailedDescriptionWithConstraints(Rules& r);
 };
 
 #endif
