@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Mar 15 2003
     copyright            : (C) 2003 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,7 +18,7 @@
 
 #ifndef GENETICTIMETABLE_DEFS
 #define GENETICTIMETABLE_DEFS
-
+//#define WIN32
 #ifdef NDEBUG
 #undef NDEBUG
 #endif
@@ -60,7 +60,7 @@ const int MAX_POPULATION_SIZE=8192;
 /**
 The maximum number of different years of students
 */
-const int MAX_YEARS=70;
+const int MAX_YEARS=100;
 
 /**
 Maximum number of allowed groups per year of students
@@ -92,9 +92,9 @@ const int MAX_SUBGROUPS_PER_ACTIVITY=400;//MAX_SUBGROUPS_PER_GROUP * MAX_GROUPS_
 This constant represents the maximum number of teachers
 for any activity.
 */
-const int MAX_TEACHERS_PER_ACTIVITY = 6;
+const int MAX_TEACHERS_PER_ACTIVITY = 100;
 
-const int MAX_SUBGROUPS_PER_CONSTRAINT=100;//MAX_SUBGROUPS_PER_GROUP * MAX_GROUPS_PER_YEAR;
+const int MAX_SUBGROUPS_PER_CONSTRAINT=400;//MAX_SUBGROUPS_PER_GROUP * MAX_GROUPS_PER_YEAR;
 
 /**
 The maximum number of different teachers
@@ -121,6 +121,11 @@ The maximum number of equipments for a constraint subject requires equipments
 */
 const int MAX_EQUIPMENTS_FOR_A_CONSTRAINT=50;
 
+/**
+The maximum number of buildings
+*/
+const int MAX_BUILDINGS=100;
+
 /**
 The maximum number of rooms
 */
@@ -235,6 +240,20 @@ const int MAX_CONSTRAINT_ACTIVITY_PREFERRED_ROOMS=20;
 /**
 The maximum number of rooms for a single
 constraint of type
+ConstraintSubjectPreferredRooms
+*/
+const int MAX_CONSTRAINT_SUBJECT_PREFERRED_ROOMS=20;
+
+/**
+The maximum number of rooms for a single
+constraint of type
+ConstraintSubjectSubjectTagPreferredRooms
+*/
+const int MAX_CONSTRAINT_SUBJECT_SUBJECT_TAG_PREFERRED_ROOMS=20;
+
+/**
+The maximum number of activities for a single
+constraint of type
 ConstraintActivitiesSameRoom
 */
 const int MAX_CONSTRAINT_ACTIVITIES_SAME_ROOM=20;
@@ -251,6 +270,13 @@ This constant is used (for now) in ConstraintTeacherRequiresRoom.
 */
 const int MAX_ACTIVITIES_FOR_A_TEACHER=200;
 
+/**
+The maximum number of activities which share the same teacher name 
+and subject name. This constant is used (for now) in 
+ConstraintTeacherSubjectRequireRoom.
+*/
+const int MAX_ACTIVITIES_FOR_A_TEACHER_AND_SUBJECT=200;
+
 
 /**
 File and directory separator
@@ -349,15 +375,37 @@ const QString ROOMS_TIMETABLE_FILENAME_XML="roomstimetable.xml";
 
 /**
 An output file containing the timetable for each subgroup,
-arranged in html format
+arranged in html format. Version 1 - flyers for each subgroup
+Days horizontal version.
 */
-const QString STUDENTS_TIMETABLE_FILENAME_HTML="studentstimetable.html";
+const QString STUDENTS_TIMETABLE_1_DAYS_HORIZONTAL_FILENAME_HTML="studentstimetable1dayshorizontal.html";
+
+/**
+An output file containing the timetable for each subgroup,
+arranged in html format. Version 1 - flyers for each subgroup
+Days vertical version.
+*/
+const QString STUDENTS_TIMETABLE_1_DAYS_VERTICAL_FILENAME_HTML="studentstimetable1daysvertical.html";
+
+/**
+An output file containing the timetable for each subgroup,
+arranged in html format. Version 2 - overall
+*/
+const QString STUDENTS_TIMETABLE_2_FILENAME_HTML="studentstimetable2.html";
 
 /**
 An output file containing the timetable for each teacher,
 arranged in html format. Version 1 - flyers for each teacher
+Days horizontal version.
 */
-const QString TEACHERS_TIMETABLE_1_FILENAME_HTML="teacherstimetable1.html";
+const QString TEACHERS_TIMETABLE_1_DAYS_HORIZONTAL_FILENAME_HTML="teacherstimetable1dayshorizontal.html";
+
+/**
+An output file containing the timetable for each teacher,
+arranged in html format. Version 1 - flyers for each teacher
+Days vertical version.
+*/
+const QString TEACHERS_TIMETABLE_1_DAYS_VERTICAL_FILENAME_HTML="teacherstimetable1daysvertical.html";
 
 /**
 An output file containing the timetable for each teacher,
@@ -367,21 +415,86 @@ const QString TEACHERS_TIMETABLE_2_FILENAME_HTML="teacherstimetable2.html";
 
 /**
 An output file containing the timetable for each room,
-arranged in html format
+arranged in html format.
+Days horizontal version.
 */
-const QString ROOMS_TIMETABLE_FILENAME_HTML="roomstimetable.html";
+const QString ROOMS_TIMETABLE_DAYS_HORIZONTAL_FILENAME_HTML="roomstimetabledayshorizontal.html";
+
+/**
+An output file containing the timetable for each room,
+arranged in html format.
+Days vertical version.
+*/
+const QString ROOMS_TIMETABLE_DAYS_VERTICAL_FILENAME_HTML="roomstimetabledaysvertical.html";
+
+/**
+An output file containing the timetable for each room,
+arranged in html format. Version 1 - flyers for each room.
+Days horizontal.
+*/
+const QString ROOMS_TIMETABLE_1_DAYS_HORIZONTAL_FILENAME_HTML="roomstimetable1dayshorizontal.html";
+
+/**
+An output file containing the timetable for each room,
+arranged in html format. Version 1 - flyers for each room.
+Days vertical.
+*/
+const QString ROOMS_TIMETABLE_1_DAYS_VERTICAL_FILENAME_HTML="roomstimetable1daysvertical.html";
+
+/**
+An output file containing the timetable for each room,
+arranged in html format. Version 2 - overall.
+*/
+const QString ROOMS_TIMETABLE_2_FILENAME_HTML="roomstimetable2.html";
 
 /**
 An output file containing the timetable (with rooms) for each subgroup,
-arranged in html format
+arranged in html format. Version 1 - flyers for each subgroup.
+Days horizontal version.
 */
-const QString STUDENTS_TIMETABLE_WITH_ROOMS_FILENAME_HTML="studentstimetablewithrooms.html";
+const QString STUDENTS_TIMETABLE_WITH_ROOMS_1_DAYS_HORIZONTAL_FILENAME_HTML="studentstimetablewithrooms1dayshorizontal.html";
+
+/**
+An output file containing the timetable (with rooms) for each subgroup,
+arranged in html format. Version 1 - flyers for each subgroup.
+Days vertical version.
+*/
+const QString STUDENTS_TIMETABLE_WITH_ROOMS_1_DAYS_VERTICAL_FILENAME_HTML="studentstimetablewithrooms1daysvertical.html";
+
+/**
+An output file containing the timetable (with rooms) for each subgroup,
+arranged in html format. Version 2 - overall.
+Days horizontal version.
+*/
+const QString STUDENTS_TIMETABLE_WITH_ROOMS_2_FILENAME_HTML="studentstimetablewithrooms2.html";
+
+/**
+An output file containing the timetable (with rooms) for each subgroup,
+arranged in html format.
+Days horizontal version.
+*/
+const QString STUDENTS_TIMETABLE_WITH_ROOMS_DAYS_HORIZONTAL_FILENAME_HTML="studentstimetablewithroomsdayshorizontal.html";
+
+/**
+An output file containing the timetable (with rooms) for each subgroup,
+arranged in html format.
+Days vertical version.
+*/
+const QString STUDENTS_TIMETABLE_WITH_ROOMS_DAYS_VERTICAL_FILENAME_HTML="studentstimetablewithroomsdaysvertical.html";
 
 /**
 An output file containing the timetable for each teacher (with rooms),
-arranged in html format. Version 1 - flyers for each teacher
+arranged in html format. Version 1 - flyers for each teacher.
+Days horizontal version.
 */
-const QString TEACHERS_TIMETABLE_WITH_ROOMS_1_FILENAME_HTML="teacherstimetablewithrooms1.html";
+const QString TEACHERS_TIMETABLE_WITH_ROOMS_1_DAYS_HORIZONTAL_FILENAME_HTML="teacherstimetablewithrooms1dayshorizontal.html";
+
+/**
+An output file containing the timetable for each teacher (with rooms),
+arranged in html format. Version 1 - flyers for each teacher.
+Days vertical version.
+*/
+const QString TEACHERS_TIMETABLE_WITH_ROOMS_1_DAYS_VERTICAL_FILENAME_HTML="teacherstimetablewithrooms1daysvertical.html";
 
 /**
 An output file containing the timetable for each teacher (with rooms),
@@ -444,4 +557,32 @@ Probability for Evolution2 propagation, in percents
 */
 extern int METHOD2_PROPAGATION_PROBABILITY;
 
+/**
+A function used in xml saving
+*/
+QString protect(const QString& str);
+
+/**
+A function used in html saving
+*/
+QString protect2(const QString& str);
+
+/**
+A function used in iCal saving
+*/
+QString protect3(const QString& str);
+
+//functions below are used in iCal exporting functions
+bool isLeapYear(int year);
+
+bool isCorrectDay(const QString day);
+
+bool isCorrectHour(const QString hour);
+
+QString nextDay(const QString day);
+
+bool sumHours(const QString hour1, const QString hour2, QString& result);
+
+QString iCalFolding(const QString s);
+
 #endif
