@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Liviu Lalescu <liviu@lalescu.ro>, (C) 2003
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2003
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -20,6 +20,7 @@
 #include <qstringlist.h>
 
 class Room;
+class Rules;
 
 class RoomsList: public QPtrList<Room>
 {
@@ -37,6 +38,15 @@ public:
 	QString type;
 	int capacity;
 	QStringList equipments;
+	/**
+	If empty string, it is ignored
+	*/
+	QString building; 
+	
+	/**
+	Internal. If -1, it is ignored
+	*/
+	int buildingIndex;
 
 	Room();
 	~Room();
@@ -44,10 +54,13 @@ public:
 	void addEquipment(const QString& equipmentName);
 	void removeEquipment(const QString& equipmentName);
 	bool searchEquipment(const QString& equipmentName);
+	
+	void computeInternalStructure(Rules& r);
 
+	QString getXmlDescription();
 	QString getDescription();
 	QString getDetailedDescription();
-	QString getXMLDescription();
+	QString getDetailedDescriptionWithConstraints(Rules& r);
 };
 
 #endif
