@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Liviu Lalescu <liviu@lalescu.ro>, (C) 2005
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2005
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -19,6 +19,7 @@
 #include <qptrlist.h>
 
 class SubjectTag;
+class Rules;
 
 class SubjectTagsList: public QPtrList<SubjectTag>
 {
@@ -37,7 +38,9 @@ public:
 	SubjectTag();
 	~SubjectTag();
 
-	QString getXMLDescription();
+	QString getXmlDescription();
+	QString getDetailedDescription();
+	QString getDetailedDescriptionWithConstraints(Rules& r);
 };
 
 #endif
