@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Liviu Lalescu <liviu@lalescu.ro>, (C) 2003
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2003
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -19,6 +19,7 @@
 #include <qptrlist.h>
 
 class Teacher;
+class Rules;
 
 class TeachersList: public QPtrList<Teacher>
 {
@@ -36,7 +37,9 @@ public:
 	Teacher();
 	~Teacher();
 
-	QString getXMLDescription();
+	QString getXmlDescription();
+	QString getDetailedDescription();
+	QString getDetailedDescriptionWithConstraints(Rules& r);
 };
 
 #endif
