@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Apr 23 2003
     copyright            : (C) 2003 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -41,17 +41,19 @@ public:
 	AddActivityForm();
 	~AddActivityForm();
 
-	void updateStudentsComboBox();
-	void updateTeachersComboBox();
+	void updateStudentsListBox();
+	void updateTeachersListBox();
 	void updateSubjectsComboBox();
 	void updateSubjectTagsComboBox();
 	void updatePreferredDaysComboBox();
 	void updatePreferredHoursComboBox();
 
-	void teacherChanged(const QString& dummy);
+	void addTeacher();
+	void removeTeacher();
+	void addStudents();
+	void removeStudents();
 	void subjectChanged(const QString& dummy);
 	void subjectTagChanged(const QString& dummy);
-	void studentsChanged(const QString& dummy);
 	void hourChanged();
 	void dayChanged();
 	void parityChanged();
@@ -59,6 +61,9 @@ public:
 	void activityChanged();
 	void splitChanged();
 	
+	void clearTeachers();
+	void clearStudents();
+	
 	void showYearsChanged();
 	void showGroupsChanged();
 	void showSubgroupsChanged();
