@@ -1,9 +1,9 @@
 /***************************************************************************
-                          constraintactivityroomform.h  -  description
+                          constraintactivitypreferredroomform.h  -  description
                              -------------------
     begin                : Feb 13, 2005
     copyright            : (C) 2005 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
