@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Liviu Lalescu <liviu@lalescu.ro>, (C) 2004
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2004
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -123,6 +123,6 @@ void EquipmentsForm::equipmentChanged(int index)
 	Equipment* equipment=gt.rules.equipmentsList.at(index);
 
 	assert(equipment!=NULL);
-	s=equipment->getDetailedDescription();
+	s=equipment->getDetailedDescriptionWithConstraints(gt.rules);
 	currentEquipmentTextEdit->setText(s);
 }
