@@ -5,7 +5,7 @@
 // Description:
 //
 //
-// Author: Lalescu Liviu <liviu@lalescu.ro>, (C) 2003
+// Author: Lalescu Liviu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2003
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -43,22 +43,34 @@ public:
 	void dataSubgroups();
 	void dataActivities();
 	void dataEquipments();
+	void dataBuildings();
 	void dataRooms();
 	void dataAllTimeConstraints();
 	void dataAllSpaceConstraints();
 
 	void dataSpaceConstraintsBasicCompulsorySpace();
 	void dataSpaceConstraintsTeacherRequiresRoom();
+	void dataSpaceConstraintsTeacherSubjectRequireRoom();
 	void dataSpaceConstraintsRoomNotAvailable();
 	void dataSpaceConstraintsActivityPreferredRoom();
 	void dataSpaceConstraintsMinimizeNumberOfRoomsForStudents();
+	void dataSpaceConstraintsMinimizeNumberOfRoomsForTeachers();
 	void dataSpaceConstraintsRoomTypeNotAllowedSubjects();
 	void dataSpaceConstraintsSubjectRequiresEquipments();
 	void dataSpaceConstraintsSubjectSubjectTagRequireEquipments();
 	void dataSpaceConstraintsActivitiesSameRoom();
 	void dataSpaceConstraintsActivityPreferredRooms();
+	void dataSpaceConstraintsSubjectPreferredRoom();
+	void dataSpaceConstraintsSubjectSubjectTagPreferredRoom();
+	void dataSpaceConstraintsSubjectPreferredRooms();
+	void dataSpaceConstraintsSubjectSubjectTagPreferredRooms();
+	void dataSpaceConstraintsMaxBuildingChangesPerDayForTeachers();
+	void dataSpaceConstraintsMaxBuildingChangesPerDayForStudents();
+	void dataSpaceConstraintsMaxRoomChangesPerDayForTeachers();
+	void dataSpaceConstraintsMaxRoomChangesPerDayForStudents();
 	
 	void dataTimeConstraints2ActivitiesConsecutive();
+	void dataTimeConstraints2ActivitiesOrdered();
 	void dataTimeConstraints2ActivitiesGrouped();
 	void dataTimeConstraintsActivitiesPreferredTimes();
 	void dataTimeConstraintsActivitiesSameStartingTime();
@@ -68,9 +80,9 @@ public:
 	void dataTimeConstraintsStudentsSetNotAvailable();
 	void dataTimeConstraintsBreak();
 	void dataTimeConstraintsTeacherMaxDaysPerWeek();
-	void dataTimeConstraintsTeachersNoMoreThanXHoursContinuously();
-	void dataTimeConstraintsTeachersNoMoreThanXHoursDaily();
-	void dataTimeConstraintsTeachersSubgroupsNoMoreThanXHoursDaily();
+	void dataTimeConstraintsTeachersMaxHoursContinuously();
+	void dataTimeConstraintsTeachersMaxHoursDaily();
+	void dataTimeConstraintsTeachersSubgroupsMaxHoursDaily();
 	void dataTimeConstraintsActivityPreferredTime();
 	void dataTimeConstraintsStudentsSetNoGaps();
 	void dataTimeConstraintsStudentsNoGaps();
@@ -83,9 +95,13 @@ public:
 	void dataTimeConstraintsActivitiesNotOverlapping();
 	void dataTimeConstraintsMinNDaysBetweenActivities();
 	void dataTimeConstraintsActivityPreferredTimes();
+	void dataTimeConstraintsTeachersSubjectTagsMaxHoursContinuously();
+	void dataTimeConstraintsTeachersSubjectTagMaxHoursContinuously();
 
 	void helpAbout();
 	void helpFAQ();
+	void helpTimeConstraints();
+	void helpTimeConstraintsSubtags();
 
 	void timetableAllocateHours();
 	void timetableViewStudents();
@@ -101,12 +117,22 @@ public:
 	void timetableShowConflictsSpace();
 	void timetableShowConflictsTimeSpace();
 	void timetableAllocateHoursRooms();
-	void timetableExport();
+	void timetableExportXmlHtml();
+	void timetableExportiCalTeachers();
+	void timetableExportiCalStudents();
+	void timetableExportiCalTeachersWithRooms1();
+	void timetableExportiCalStudentsWithRooms1();
+	void timetableExportiCalTeachersWithRooms2();
+	void timetableExportiCalStudentsWithRooms2();
 	
 	void languageEnglish();
 	void languageFrench();
 	void languageCatalan();
 	void languageRomanian();
+	void languageMalay();
+	void languagePolish();
+	void languageTurkish();
+	void languageDutch();
 	
 	void parametersPopulationNumber();
 };
