@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Lalescu Liviu <liviu@lalescu.ro>, (C) 2003
+// Author: Lalescu Liviu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2003
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -17,12 +17,17 @@
 
 class PopulationNumberForm : public PopulationNumberForm_template
 {
+	int p_n;
+	
 public:
 	PopulationNumberForm();
 
 	~PopulationNumberForm();
 
 	void populationNumberChanged();
+	
+	void ok();
+	void cancel();
 };
 
 #endif
