@@ -5,7 +5,7 @@
 // Description: 
 //
 //
-// Author: Liviu Lalescu <liviu@lalescu.ro>, (C) 2003
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2003
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -21,6 +21,8 @@
 class RoomsForm : public RoomsForm_template
 {
 public:
+	RoomsList visibleRoomsList;
+
 	RoomsForm();
 	~RoomsForm();
 
@@ -30,6 +32,8 @@ public:
 	void sortRooms();
 	void roomChanged(int index);
 	void roomsEquipments();
+	void filterChanged();
+	bool filterOk(Room* rm);
 };
 
 #endif
