@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Apr 22 2003
     copyright            : (C) 2003 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -81,13 +81,35 @@ public:
 
 	/**
 	Function writing the students' timetable html format, to a file
+	(variant 1).
+	Days horizontal version.
 	*/
-	void writeStudentsTimetableHtml(const QString& htmlfilename);
+	void writeStudentsTimetable1DaysHorizontalHtml(const QString& htmlfilename);
 
 	/**
-	Function writing the teachers' timetable in html format, version 1
+	Function writing the students' timetable html format, to a file
+	(variant 1).
+	Days vertical version.
 	*/
-	void writeTeachersTimetable1Html(const QString& htmlfilename);
+	void writeStudentsTimetable1DaysVerticalHtml(const QString& htmlfilename);
+
+	/**
+	Function writing the students' timetable html format, to a file
+	(variant 2)
+	*/
+	void writeStudentsTimetable2Html(const QString& htmlfilename);
+
+	/**
+	Function writing the teachers' timetable in html format, version 1.
+	Days horizontal version
+	*/
+	void writeTeachersTimetable1DaysHorizontalHtml(const QString& htmlfilename);
+
+	/**
+	Function writing the teachers' timetable in html format, version 1.
+	Days vertical version
+	*/
+	void writeTeachersTimetable1DaysVerticalHtml(const QString& htmlfilename);
 
 	/**
 	Function writing the teachers' timetable in html format, version 2
