@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Apr 22 2003
     copyright            : (C) 2003 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -48,7 +48,7 @@ static SpaceSolvingThread spaceSolvingThread;
 extern QApplication *pqapplication;
 
 //Represents the current state - simulation running or stopped.
-static bool simulation_running;
+extern bool simulation_running;
 
 //Communication variables when the simulation is running.
 static bool simulation_stopped=false;
@@ -60,6 +60,8 @@ extern bool students_schedule_ready;
 extern bool teachers_schedule_ready;
 extern bool rooms_schedule_ready;
 
+extern SpaceChromosome best_space_chromosome;
+
 extern QString spaceConflictsString;
 
 TimetableAllocateRoomsForm::TimetableAllocateRoomsForm()
@@ -330,6 +332,19 @@ void TimetableAllocateRoomsForm::writeSimulationResults(SpaceChromosome &c){
 	if(&c!=NULL)
 		;
 
+	QDir dir;
+	
+	//make sure that the input directory exists - only for GNU/Linux
+	//For Windows, I make a "fet.ini" in the current working directory
+#ifndef WIN32
+	if(!dir.exists(QDir::homeDirPath()+"/.fet"))
+		dir.mkdir(QDir::homeDirPath()+"/.fet");
+#endif
+
+	//make sure that the output directory exists
+	if(!dir.exists(OUTPUT_DIR))
+		dir.mkdir(OUTPUT_DIR);
+
 	assert(gt.rules.initialized && gt.rules.internalStructureComputed);
 	assert(gt.spacePopulation.initialized);
 	assert(students_schedule_ready && teachers_schedule_ready);
@@ -349,18 +364,24 @@ void TimetableAllocateRoomsForm::writeSimulationResults(SpaceChromosome &c){
 	file.close();
 	//now write the solution in xml and html
 	//students - html
-	s=OUTPUT_DIR+FILE_SEP+s2+"_"+STUDENTS_TIMETABLE_WITH_ROOMS_FILENAME_HTML;
-	writeStudentsTimetableWithRoomsHtml(s);
+	s=OUTPUT_DIR+FILE_SEP+s2+"_"+STUDENTS_TIMETABLE_WITH_ROOMS_DAYS_HORIZONTAL_FILENAME_HTML;
+	writeStudentsTimetableWithRoomsDaysHorizontalHtml(s);
+	s=OUTPUT_DIR+FILE_SEP+s2+"_"+STUDENTS_TIMETABLE_WITH_ROOMS_DAYS_VERTICAL_FILENAME_HTML;
+	writeStudentsTimetableWithRoomsDaysVerticalHtml(s);
 	//teachers - html
-	s=OUTPUT_DIR+FILE_SEP+s2+"_"+TEACHERS_TIMETABLE_WITH_ROOMS_1_FILENAME_HTML;
-	writeTeachersTimetableWithRooms1Html(s);
+	s=OUTPUT_DIR+FILE_SEP+s2+"_"+TEACHERS_TIMETABLE_WITH_ROOMS_1_DAYS_HORIZONTAL_FILENAME_HTML;
+	writeTeachersTimetableWithRooms1DaysHorizontalHtml(s);
+	s=OUTPUT_DIR+FILE_SEP+s2+"_"+TEACHERS_TIMETABLE_WITH_ROOMS_1_DAYS_VERTICAL_FILENAME_HTML;
+	writeTeachersTimetableWithRooms1DaysVerticalHtml(s);
 	s=OUTPUT_DIR+FILE_SEP+s2+"_"+TEACHERS_TIMETABLE_WITH_ROOMS_2_FILENAME_HTML;
 	writeTeachersTimetableWithRooms2Html(s);
 	//rooms - xml and html
 	s=OUTPUT_DIR+FILE_SEP+s2+"_"+ROOMS_TIMETABLE_FILENAME_XML;
 	writeRoomsTimetableXml(s);
-	s=OUTPUT_DIR+FILE_SEP+s2+"_"+ROOMS_TIMETABLE_FILENAME_HTML;
-	writeRoomsTimetableHtml(s);
+	s=OUTPUT_DIR+FILE_SEP+s2+"_"+ROOMS_TIMETABLE_DAYS_HORIZONTAL_FILENAME_HTML;
+	writeRoomsTimetableDaysHorizontalHtml(s);
+	s=OUTPUT_DIR+FILE_SEP+s2+"_"+ROOMS_TIMETABLE_DAYS_VERTICAL_FILENAME_HTML;
+	writeRoomsTimetableDaysVerticalHtml(s);
 
 	cout<<"Writing simulation results to disk completed successfully"<<endl;
 }
@@ -371,6 +392,7 @@ void TimetableAllocateRoomsForm::getRoomsTimetable(SpaceChromosome &c){
 
 	//assert(c.HFitness()==0); - for perfect solutions
 	c.getRoomsTimetable(gt.rules, gt.spacePopulation.days, gt.spacePopulation.hours, rooms_timetable_week1, rooms_timetable_week2);
+	best_space_chromosome.copy(gt.rules, c);
 	rooms_schedule_ready=true;
 }
 
@@ -389,30 +411,34 @@ void TimetableAllocateRoomsForm::writeRoomsTimetableXml(const QString& xmlfilena
 	if(!file.open(IO_WriteOnly))
 		assert(0);
 	QTextStream tos(&file);
-	tos << "<" << ROOMS_TIMETABLE_TAG << ">\n";
+	tos << "<" << protect(ROOMS_TIMETABLE_TAG) << ">\n";
 
 	for(int i=0; i<gt.rules.nInternalRooms; i++){
 		tos<<"\n";
-		tos << "  <Room name=\"" << gt.rules.internalRoomsList[i]->name << "\">\n";
+		tos << "  <Room name=\"" << protect(gt.rules.internalRoomsList[i]->name) << "\">\n";
 		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
-			tos << "   <Day name=\"" << gt.rules.daysOfTheWeek[k] << "\">\n";
+			tos << "   <Day name=\"" << protect(gt.rules.daysOfTheWeek[k]) << "\">\n";
 			for(int j=0; j<gt.rules.nHoursPerDay; j++){
-				tos << "    <Hour name=\"" << gt.rules.hoursOfTheDay[j] << "\">\n";
+				tos << "    <Hour name=\"" << protect(gt.rules.hoursOfTheDay[j]) << "\">\n";
 
 				tos<<"     <Week1>";
 				int ai=rooms_timetable_week1[i][k][j]; //activity index
-				Activity* act=gt.rules.activitiesList.at(ai);
-				if(ai!=UNALLOCATED_ACTIVITY)
+				//Activity* act=gt.rules.activitiesList.at(ai);
+				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
-						tos << "<Students name=\"" << *it << "\"></Students>";
+						tos << "<Students name=\"" << protect(*it) << "\"></Students>";
+				}
 				tos<<"</Week1>\n";
 
 				tos<<"     <Week2>";
 				ai=rooms_timetable_week2[i][k][j]; //activity index
-				act=gt.rules.activitiesList.at(ai);
-				if(ai!=UNALLOCATED_ACTIVITY)
+				//act=gt.rules.activitiesList.at(ai);
+				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
-						tos << "<Students name=\"" << *it << "\"></Students>";
+						tos << "<Students name=\"" << protect(*it) << "\"></Students>";
+				}
 				tos<<"</Week2>\n";
 
 				tos << "    </Hour>\n";
@@ -423,15 +449,16 @@ void TimetableAllocateRoomsForm::writeRoomsTimetableXml(const QString& xmlfilena
 	}
 
 	tos<<"\n";
-	tos << "</" << ROOMS_TIMETABLE_TAG << ">\n";
+	tos << "</" << protect(ROOMS_TIMETABLE_TAG) << ">\n";
 
 	file.close();
 }
 
 /**
-Function writing the students' timetable (with rooms) in html format to a file
+Function writing the students' timetable (with rooms) in html format to a file.
+Days horizontal.
 */
-void TimetableAllocateRoomsForm::writeStudentsTimetableWithRoomsHtml(const QString& htmlfilename)
+void TimetableAllocateRoomsForm::writeStudentsTimetableWithRoomsDaysHorizontalHtml(const QString& htmlfilename)
 {
 	assert(gt.rules.initialized && gt.rules.internalStructureComputed);
 	assert(gt.timePopulation.initialized);
@@ -446,41 +473,42 @@ void TimetableAllocateRoomsForm::writeStudentsTimetableWithRoomsHtml(const QStri
 	QTextStream tos(&file);
 
 	tos<<"<html>\n";
-	tos<<"<title>"<<gt.rules.institutionName<<"</title>\n";
+	tos<<"<title>"<<protect2(gt.rules.institutionName)<<"</title>\n";
 	tos<<"<body>\n";
 	
-	tos<<"<center><h3>"<<gt.rules.institutionName<<"</h3></center><br>\n";
+	tos<<"<center><h3>"<<protect2(gt.rules.institutionName)<<"</h3></center><br>\n";
 
 	for(int subgroup=0; subgroup<gt.rules.nInternalSubgroups; subgroup++){
 		QString subgroup_name = gt.rules.internalSubgroupsList[subgroup]->name;
-		tos<<"<p align=\"center\">"<<subgroup_name<<"</p>\n";		
+		tos<<"<p align=\"center\">"<<protect2(subgroup_name)<<"</p>\n";		
 		tos<<"<table border=\"1\" cellpadding=\"6\">"<<endl;
 
 		tos<<"<tr>\n<td></td>\n";
-		for(int j=0; j<gt.rules.nHoursPerDay; j++)
-			tos<<"<td>"<<gt.rules.hoursOfTheDay[j]<<"</td>\n";		
+		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
+			tos<<"<td>"<<protect2(gt.rules.daysOfTheWeek[j])<<"</td>\n";		
 		tos<<"</tr>\n";
 
-		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
+		for(int j=0; j<gt.rules.nHoursPerDay; j++){
 			tos<<"<tr>\n";
-			tos<<"<td>"<<gt.rules.daysOfTheWeek[k]<<"</td>\n";
+			tos<<"<td>"<<protect2(gt.rules.hoursOfTheDay[j])<<"</td>\n";
 			
-			for(int j=0; j<gt.rules.nHoursPerDay; j++){
+			for(int k=0; k<gt.rules.nDaysPerWeek; k++){
 				tos<<"<td style=\"width:14em;\">\n";
 				
 				int ai=students_timetable_week1[subgroup][k][j]; //activity index
 				if(ai!=UNALLOCATED_ACTIVITY){
-					Activity* act=gt.rules.activitiesList.at(ai);
+					//Activity* act=gt.rules.activitiesList.at(ai);
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
-						tos<<(*it)<<"<br/>";
-					tos<<act->subjectName<<" "<<act->subjectTagName<<"<br/>";
+						tos<<protect2(*it)<<"<br/>";
+					tos<<protect2(act->subjectName)<<" "<<protect2(act->subjectTagName)<<"<br/>";
 					
 					int ri=c.rooms[ai]; //room index
 					QString roomName;
 					if(ri==UNALLOCATED_SPACE)
 						roomName="UNALLOCATED_SPACE";
 					else
-						roomName=gt.rules.roomsList.at(ri)->name;
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
 					tos<<roomName<<"<br/>";
 				}
 				else
@@ -488,17 +516,18 @@ void TimetableAllocateRoomsForm::writeStudentsTimetableWithRoomsHtml(const QStri
 				ai=students_timetable_week2[subgroup][k][j]; //activity index
 				if(ai!=UNALLOCATED_ACTIVITY){
 					tos<<"/<br/>";
-					Activity* act=gt.rules.activitiesList.at(ai);
+					//Activity* act=gt.rules.activitiesList.at(ai);
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
-						tos<<(*it)<<"<br/>";
-					tos<<act->subjectName<<" "<<act->subjectTagName<<"<br/>";
+						tos<<protect2(*it)<<"<br/>";
+					tos<<protect2(act->subjectName)<<" "<<protect2(act->subjectTagName)<<"<br/>";
 
 					int ri=c.rooms[ai]; //room index
 					QString roomName;
 					if(ri==UNALLOCATED_SPACE)
 						roomName="UNALLOCATED_SPACE";
 					else
-						roomName=gt.rules.roomsList.at(ri)->name;
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
 					tos<<roomName<<"<br/>";
 				}
 				tos<<"</td>\n";
@@ -508,15 +537,116 @@ void TimetableAllocateRoomsForm::writeStudentsTimetableWithRoomsHtml(const QStri
 		tos<<"</table>\n";
 	}
 
+	tos<<"<p/>"<<endl;
+	time_t ltime;
+	tzset();
+	time(&ltime);
+	tos<<QObject::tr("Timetable generated with FET %1 on %2").arg(FET_VERSION).arg(ctime(&ltime));
+					
 	tos<<"</body>\n</html>\n";
 
 	file.close();
 }
 
 /**
-Function writing the teachers' timetable (with rooms) html format to a file (var. 1)
+Function writing the students' timetable (with rooms) in html format to a file.
+Days vertical.
 */
-void TimetableAllocateRoomsForm::writeTeachersTimetableWithRooms1Html(const QString& htmlfilename)
+void TimetableAllocateRoomsForm::writeStudentsTimetableWithRoomsDaysVerticalHtml(const QString& htmlfilename)
+{
+	assert(gt.rules.initialized && gt.rules.internalStructureComputed);
+	assert(gt.timePopulation.initialized);
+	assert(students_schedule_ready && teachers_schedule_ready && rooms_schedule_ready);
+
+	SpaceChromosome& c=gt.spacePopulation.bestChromosome(gt.rules);
+
+	//Now we print the results to an HTML file
+	QFile file(htmlfilename);
+	if(!file.open(IO_WriteOnly))
+		assert(0);
+	QTextStream tos(&file);
+
+	tos<<"<html>\n";
+	tos<<"<title>"<<protect2(gt.rules.institutionName)<<"</title>\n";
+	tos<<"<body>\n";
+	
+	tos<<"<center><h3>"<<protect2(gt.rules.institutionName)<<"</h3></center><br>\n";
+
+	for(int subgroup=0; subgroup<gt.rules.nInternalSubgroups; subgroup++){
+		QString subgroup_name = gt.rules.internalSubgroupsList[subgroup]->name;
+		tos<<"<p align=\"center\">"<<protect2(subgroup_name)<<"</p>\n";		
+		tos<<"<table border=\"1\" cellpadding=\"6\">"<<endl;
+
+		tos<<"<tr>\n<td></td>\n";
+		for(int j=0; j<gt.rules.nHoursPerDay; j++)
+			tos<<"<td>"<<protect2(gt.rules.hoursOfTheDay[j])<<"</td>\n";		
+		tos<<"</tr>\n";
+
+		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
+			tos<<"<tr>\n";
+			tos<<"<td>"<<protect2(gt.rules.daysOfTheWeek[k])<<"</td>\n";
+			
+			for(int j=0; j<gt.rules.nHoursPerDay; j++){
+				tos<<"<td style=\"width:14em;\">\n";
+				
+				int ai=students_timetable_week1[subgroup][k][j]; //activity index
+				if(ai!=UNALLOCATED_ACTIVITY){
+					//Activity* act=gt.rules.activitiesList.at(ai);
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+						tos<<protect2(*it)<<"<br/>";
+					tos<<protect2(act->subjectName)<<" "<<protect2(act->subjectTagName)<<"<br/>";
+					
+					int ri=c.rooms[ai]; //room index
+					QString roomName;
+					if(ri==UNALLOCATED_SPACE)
+						roomName="UNALLOCATED_SPACE";
+					else
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
+					tos<<roomName<<"<br/>";
+				}
+				else
+					tos<<"&nbsp;";
+				ai=students_timetable_week2[subgroup][k][j]; //activity index
+				if(ai!=UNALLOCATED_ACTIVITY){
+					tos<<"/<br/>";
+					//Activity* act=gt.rules.activitiesList.at(ai);
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+						tos<<protect2(*it)<<"<br/>";
+					tos<<protect2(act->subjectName)<<" "<<protect2(act->subjectTagName)<<"<br/>";
+
+					int ri=c.rooms[ai]; //room index
+					QString roomName;
+					if(ri==UNALLOCATED_SPACE)
+						roomName="UNALLOCATED_SPACE";
+					else
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
+					tos<<roomName<<"<br/>";
+				}
+				tos<<"</td>\n";
+			}			
+			tos<<"</tr>\n";
+		}		
+		tos<<"</table>\n";
+	}
+
+	tos<<"<p/>"<<endl;
+	time_t ltime;
+	tzset();
+	time(&ltime);
+	tos<<QObject::tr("Timetable generated with FET %1 on %2").arg(FET_VERSION).arg(ctime(&ltime));
+					
+	tos<<"</body>\n</html>\n";
+
+	file.close();
+}
+
+/**
+Function writing the teachers' timetable (with rooms) html format to a file (var. 1).
+Days horizontal.
+*/
+void TimetableAllocateRoomsForm::writeTeachersTimetableWithRooms1DaysHorizontalHtml(const QString& htmlfilename)
 {
 	assert(gt.rules.initialized && gt.rules.internalStructureComputed);
 	assert(gt.timePopulation.initialized);
@@ -529,17 +659,108 @@ void TimetableAllocateRoomsForm::writeTeachersTimetableWithRooms1Html(const QStr
 	if(!file.open(IO_WriteOnly))
 		assert(0);
 	QTextStream tos(&file);
-	tos<<"<html>\n<title>"<<gt.rules.institutionName<<"</title>\n";
+	tos<<"<html>\n<title>"<<protect2(gt.rules.institutionName)<<"</title>\n";
 	tos<<"<body>\n";
-	tos<<"<center><h3>"<<gt.rules.institutionName<<"</h3></center><br>\n";
+	tos<<"<center><h3>"<<protect2(gt.rules.institutionName)<<"</h3></center><br>\n";
 
 	for(int i=0; i<gt.rules.nInternalTeachers; i++){
-		tos<<"<p align=\"center\">"<<gt.rules.internalTeachersList[i]->name<<"</p>\n";
+		tos<<"<p align=\"center\">"<<protect2(gt.rules.internalTeachersList[i]->name)<<"</p>\n";
+		tos<<"<table width=\"100%\" border=\"1\" cellpadding=\"6\">\n";
+
+		tos<<"<tr>\n<td></td>\n";
+		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
+			tos << "<td>" << protect2(gt.rules.daysOfTheWeek[j]) << "</td>\n";
+		tos<<"</tr>\n";
+		
+		for(int j=0; j<gt.rules.nHoursPerDay; j++){
+			tos<<"<tr>\n";
+			
+			tos<<"<td>"<<gt.rules.hoursOfTheDay[j]<<"</td>\n";
+			for(int k=0; k<gt.rules.nDaysPerWeek; k++){
+				tos<<"<td style=\"width:14em;\">";
+
+				int ai=teachers_timetable_week1[i][k][j]; //activity index
+				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+						tos << protect2(*it) << "<br/>";
+						
+					tos<<protect2(act->subjectName)<<" "<<protect2(act->subjectTagName)<<"<br/>";
+					
+					int ri=c.rooms[ai]; //room index
+					QString roomName;
+					if(ri==UNALLOCATED_SPACE)
+						roomName="UNALLOCATED_SPACE";
+					else
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
+					tos<<roomName<<"<br/>";
+				}
+				else
+					tos<<"&nbsp;";
+
+				ai=teachers_timetable_week2[i][k][j]; //activity index
+				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					tos<<"/<br/>\n";
+					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+						tos << protect2(*it) << "<br/>";
+					
+					tos<<protect2(act->subjectName)<<" "<<protect2(act->subjectTagName)<<"<br/>";
+
+					int ri=c.rooms[ai]; //room index
+					QString roomName;
+					if(ri==UNALLOCATED_SPACE)
+						roomName="UNALLOCATED_SPACE";
+					else
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
+					tos<<roomName<<"<br/>";
+				}
+				tos<<"</td>\n";
+			}
+			tos << "</tr>\n";
+		}
+		tos<<"</table>\n";
+	}
+
+	tos<<"<p/>"<<endl;
+	time_t ltime;
+	tzset();
+	time(&ltime);
+	tos<<QObject::tr("Timetable generated with FET %1 on %2").arg(FET_VERSION).arg(ctime(&ltime));
+
+	tos<<"</body>\n</html>\n";
+
+	file.close();
+}
+
+/**
+Function writing the teachers' timetable (with rooms) html format to a file (var. 1).
+Days vertical.
+*/
+void TimetableAllocateRoomsForm::writeTeachersTimetableWithRooms1DaysVerticalHtml(const QString& htmlfilename)
+{
+	assert(gt.rules.initialized && gt.rules.internalStructureComputed);
+	assert(gt.timePopulation.initialized);
+	assert(students_schedule_ready && teachers_schedule_ready && rooms_schedule_ready);
+
+	SpaceChromosome& c=gt.spacePopulation.bestChromosome(gt.rules);
+
+	//Writing the timetable in xml format
+	QFile file(htmlfilename);
+	if(!file.open(IO_WriteOnly))
+		assert(0);
+	QTextStream tos(&file);
+	tos<<"<html>\n<title>"<<protect2(gt.rules.institutionName)<<"</title>\n";
+	tos<<"<body>\n";
+	tos<<"<center><h3>"<<protect2(gt.rules.institutionName)<<"</h3></center><br>\n";
+
+	for(int i=0; i<gt.rules.nInternalTeachers; i++){
+		tos<<"<p align=\"center\">"<<protect2(gt.rules.internalTeachersList[i]->name)<<"</p>\n";
 		tos<<"<table width=\"100%\" border=\"1\" cellpadding=\"6\">\n";
 
 		tos<<"<tr>\n<td></td>\n";
 		for(int j=0; j<gt.rules.nHoursPerDay; j++)
-			tos << "<td>" << gt.rules.hoursOfTheDay[j] << "</td>\n";
+			tos << "<td>" << protect2(gt.rules.hoursOfTheDay[j]) << "</td>\n";
 		tos<<"</tr>\n";
 		
 		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
@@ -550,35 +771,41 @@ void TimetableAllocateRoomsForm::writeTeachersTimetableWithRooms1Html(const QStr
 				tos<<"<td style=\"width:14em;\">";
 
 				int ai=teachers_timetable_week1[i][k][j]; //activity index
-				Activity* act=gt.rules.activitiesList.at(ai);
+				//Activity* act=gt.rules.activitiesList.at(ai);
 				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
-						tos << *it << "<br/>";
+						tos << protect2(*it) << "<br/>";
+						
+					tos<<protect2(act->subjectName)<<" "<<protect2(act->subjectTagName)<<"<br/>";
 					
 					int ri=c.rooms[ai]; //room index
 					QString roomName;
 					if(ri==UNALLOCATED_SPACE)
 						roomName="UNALLOCATED_SPACE";
 					else
-						roomName=gt.rules.roomsList.at(ri)->name;
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
 					tos<<roomName<<"<br/>";
 				}
 				else
 					tos<<"&nbsp;";
 
 				ai=teachers_timetable_week2[i][k][j]; //activity index
-				act=gt.rules.activitiesList.at(ai);
+				//act=gt.rules.activitiesList.at(ai);
 				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					tos<<"/<br/>\n";
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
-						tos << *it << "<br/>";
+						tos << protect2(*it) << "<br/>";
 					
+					tos<<protect2(act->subjectName)<<" "<<protect2(act->subjectTagName)<<"<br/>";
+
 					int ri=c.rooms[ai]; //room index
 					QString roomName;
 					if(ri==UNALLOCATED_SPACE)
 						roomName="UNALLOCATED_SPACE";
 					else
-						roomName=gt.rules.roomsList.at(ri)->name;
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
 					tos<<roomName<<"<br/>";
 				}
 				tos<<"</td>\n";
@@ -587,6 +814,13 @@ void TimetableAllocateRoomsForm::writeTeachersTimetableWithRooms1Html(const QStr
 		}
 		tos<<"</table>\n";
 	}
+
+	tos<<"<p/>"<<endl;
+	time_t ltime;
+	tzset();
+	time(&ltime);
+	tos<<QObject::tr("Timetable generated with FET %1 on %2").arg(FET_VERSION).arg(ctime(&ltime));
+
 	tos<<"</body>\n</html>\n";
 
 	file.close();
@@ -612,51 +846,53 @@ void TimetableAllocateRoomsForm::writeTeachersTimetableWithRooms2Html(const QStr
 	
 	tos<<"<tr><td></td>\n";
 	for(int k=0; k<gt.rules.nDaysPerWeek; k++)
-		tos << "<td align=\"center\" colspan=\"" << gt.rules.nHoursPerDay <<"\">" << gt.rules.daysOfTheWeek[k] << "</td>\n";
+		tos << "<td align=\"center\" colspan=\"" << gt.rules.nHoursPerDay <<"\">" << protect2(gt.rules.daysOfTheWeek[k]) << "</td>\n";
 	tos<<"</tr>\n";
 
 	tos<<"<tr>\n";
 	tos<<"<td></td>\n";
 	for(int k=0; k<gt.rules.nDaysPerWeek; k++)
 		for(int j=0; j<gt.rules.nHoursPerDay; j++)
-			tos << "<td>" << gt.rules.hoursOfTheDay[j] << "</td>\n";
+			tos << "<td>" << protect2(gt.rules.hoursOfTheDay[j]) << "</td>\n";
 
 	for(int i=0; i<gt.rules.nInternalTeachers; i++){
 		tos<<"<tr>\n";
-		tos << "<td>" << gt.rules.internalTeachersList[i]->name << "</td>\n";
+		tos << "<td>" << protect2(gt.rules.internalTeachersList[i]->name) << "</td>\n";
 		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
 			for(int j=0; j<gt.rules.nHoursPerDay; j++){
 				tos<<"<td>";
 				int ai=teachers_timetable_week1[i][k][j]; //activity index
-				Activity* act=gt.rules.activitiesList.at(ai);
+				//Activity* act=gt.rules.activitiesList.at(ai);
 				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
-						tos<<*it<<"<br/>";
+						tos<<protect2(*it)<<"<br/>";
 
 					int ri=c.rooms[ai]; //room index
 					QString roomName;
 					if(ri==UNALLOCATED_SPACE)
 						roomName="UNALLOCATED_SPACE";
 					else
-						roomName=gt.rules.roomsList.at(ri)->name;
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
 					tos<<roomName<<"<br/>";
 				}
 				else
 					tos<<"&nbsp;";
 
 				ai=teachers_timetable_week2[i][k][j]; //activity index
-				act=gt.rules.activitiesList.at(ai);
+				//act=gt.rules.activitiesList.at(ai);
 				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					tos<<"/<br/>";
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
-						tos << *it <<"<br/>";
+						tos << protect2(*it) <<"<br/>";
 
 					int ri=c.rooms[ai]; //room index
 					QString roomName;
 					if(ri==UNALLOCATED_SPACE)
 						roomName="UNALLOCATED_SPACE";
 					else
-						roomName=gt.rules.roomsList.at(ri)->name;
+						roomName=protect2(gt.rules.roomsList.at(ri)->name);
 					tos<<roomName<<"<br/>";
 				}
 				tos<<"</td>\n";
@@ -665,15 +901,24 @@ void TimetableAllocateRoomsForm::writeTeachersTimetableWithRooms2Html(const QStr
 		tos<<"</tr>\n";
 	}
 
-	tos<<"</table>\n</body>\n</html>\n";
+	tos<<"</table>\n";
+	
+	tos<<"<p/>"<<endl;
+	time_t ltime;
+	tzset();
+	time(&ltime);
+	tos<<QObject::tr("Timetable generated with FET %1 on %2").arg(FET_VERSION).arg(ctime(&ltime));
+	
+	tos<<"</body>\n</html>\n";
 
 	file.close();
 }
 
 /**
-Function writing the rooms' timetable in html format to a file
+Function writing the rooms' timetable in html format to a file.
+Days horizontal.
 */
-void TimetableAllocateRoomsForm::writeRoomsTimetableHtml(const QString& htmlfilename)
+void TimetableAllocateRoomsForm::writeRoomsTimetableDaysHorizontalHtml(const QString& htmlfilename)
 {
 	assert(gt.rules.initialized && gt.rules.internalStructureComputed);
 	assert(gt.spacePopulation.initialized);
@@ -686,39 +931,42 @@ void TimetableAllocateRoomsForm::writeRoomsTimetableHtml(const QString& htmlfile
 		assert(0);
 	QTextStream tos(&file);
 	tos<<"<html>\n";
-	tos<<"<title>"<<gt.rules.institutionName<<"</title>\n";
+	tos<<"<title>"<<protect2(gt.rules.institutionName)<<"</title>\n";
 	tos<<"<body>";
-	tos<<"<center><h3>"<<gt.rules.institutionName<<"</h3></center><br/>\n";
+	tos<<"<center><h3>"<<protect2(gt.rules.institutionName)<<"</h3></center><br/>\n";
 
 	for(int i=0; i<gt.rules.nInternalRooms; i++){
-		tos<<"<p align=\"center\">"<<gt.rules.internalRoomsList[i]->name<<"</p>\n";
+		tos<<"<p align=\"center\">"<<protect2(gt.rules.internalRoomsList[i]->name)<<"</p>\n";
 		tos<<"<table border=\"1\" cellpadding=\"6\">\n";
 
 		tos<<"<tr>\n<td>&nbsp;</td>\n";
-		for(int j=0; j<gt.rules.nHoursPerDay; j++)
-			tos << "<td>" << gt.rules.hoursOfTheDay[j] << "</td>\n";
+		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
+			tos << "<td>" << protect2(gt.rules.daysOfTheWeek[j]) << "</td>\n";
 		tos<<"</tr>\n";
 
-		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
+		for(int j=0; j<gt.rules.nHoursPerDay; j++){
 			tos<<"<tr>\n";
-			tos << "<td>" << gt.rules.daysOfTheWeek[k] << "</td>\n";
-			for(int j=0; j<gt.rules.nHoursPerDay; j++){
+			tos << "<td>" << protect2(gt.rules.hoursOfTheDay[j]) << "</td>\n";
+			for(int k=0; k<gt.rules.nDaysPerWeek; k++){
 				tos << "<td>";
 
 				int ai=rooms_timetable_week1[i][k][j]; //activity index
-				Activity* act=gt.rules.activitiesList.at(ai);
-				if(ai!=UNALLOCATED_ACTIVITY)
+				//Activity* act=gt.rules.activitiesList.at(ai);
+				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
-						tos << *it << "<br/>";
+						tos << protect2(*it) << "<br/>";
+				}
 				else
 					tos<<"&nbsp;";
 
 				ai=rooms_timetable_week2[i][k][j]; //activity index
-				act=gt.rules.activitiesList.at(ai);
+				//act=gt.rules.activitiesList.at(ai);
 				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					tos<<"/<br/>";
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
-						tos << *it << "<br/>";
+						tos << protect2(*it) << "<br/>";
 				}
 
 				tos << "</td>\n";
@@ -728,6 +976,85 @@ void TimetableAllocateRoomsForm::writeRoomsTimetableHtml(const QString& htmlfile
 		tos<<"</table>\n";
 	}
 
+	tos<<"<p/>"<<endl;
+	time_t ltime;
+	tzset();
+	time(&ltime);
+	tos<<QObject::tr("Timetable generated with FET %1 on %2").arg(FET_VERSION).arg(ctime(&ltime));
+
+	tos<<"</body>\n</html>\n";
+
+	file.close();
+}
+
+/**
+Function writing the rooms' timetable in html format to a file.
+Days vertical.
+*/
+void TimetableAllocateRoomsForm::writeRoomsTimetableDaysVerticalHtml(const QString& htmlfilename)
+{
+	assert(gt.rules.initialized && gt.rules.internalStructureComputed);
+	assert(gt.spacePopulation.initialized);
+	assert(students_schedule_ready && teachers_schedule_ready);
+	assert(rooms_schedule_ready);
+
+	//Writing the timetable in xml format
+	QFile file(htmlfilename);
+	if(!file.open(IO_WriteOnly))
+		assert(0);
+	QTextStream tos(&file);
+	tos<<"<html>\n";
+	tos<<"<title>"<<protect2(gt.rules.institutionName)<<"</title>\n";
+	tos<<"<body>";
+	tos<<"<center><h3>"<<protect2(gt.rules.institutionName)<<"</h3></center><br/>\n";
+
+	for(int i=0; i<gt.rules.nInternalRooms; i++){
+		tos<<"<p align=\"center\">"<<protect2(gt.rules.internalRoomsList[i]->name)<<"</p>\n";
+		tos<<"<table border=\"1\" cellpadding=\"6\">\n";
+
+		tos<<"<tr>\n<td>&nbsp;</td>\n";
+		for(int j=0; j<gt.rules.nHoursPerDay; j++)
+			tos << "<td>" << protect2(gt.rules.hoursOfTheDay[j]) << "</td>\n";
+		tos<<"</tr>\n";
+
+		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
+			tos<<"<tr>\n";
+			tos << "<td>" << protect2(gt.rules.daysOfTheWeek[k]) << "</td>\n";
+			for(int j=0; j<gt.rules.nHoursPerDay; j++){
+				tos << "<td>";
+
+				int ai=rooms_timetable_week1[i][k][j]; //activity index
+				//Activity* act=gt.rules.activitiesList.at(ai);
+				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+						tos << protect2(*it) << "<br/>";
+				}
+				else
+					tos<<"&nbsp;";
+
+				ai=rooms_timetable_week2[i][k][j]; //activity index
+				//act=gt.rules.activitiesList.at(ai);
+				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					tos<<"/<br/>";
+					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+						tos << protect2(*it) << "<br/>";
+				}
+
+				tos << "</td>\n";
+			}
+			tos << "</tr>\n";
+		}
+		tos<<"</table>\n";
+	}
+
+	tos<<"<p/>"<<endl;
+	time_t ltime;
+	tzset();
+	time(&ltime);
+	tos<<QObject::tr("Timetable generated with FET %1 on %2").arg(FET_VERSION).arg(ctime(&ltime));
+
 	tos<<"</body>\n</html>\n";
 
 	file.close();
