@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed May 14 2003
     copyright            : (C) 2003 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -36,7 +36,12 @@
 #include <qlabel.h>
 #include <qtable.h>
 
-extern bool students_schedule_ready, teachers_schedule_ready;
+extern bool students_schedule_ready;
+extern bool teachers_schedule_ready;
+
+extern TimeChromosome best_time_chromosome;
+
+extern bool simulation_running;
 
 TimetableViewTeachersForm::TimetableViewTeachersForm()
 {
@@ -94,19 +99,23 @@ void TimetableViewTeachersForm::updateTeachersTimetableTable(){
 			for(int k=0; k<gt.rules.nDaysPerWeek; k++){
 				s = "";
 				int ai=teachers_timetable_week1[teacher][k][j]; //activity index
-				Activity* act=gt.rules.activitiesList.at(ai);
+				//Activity* act=gt.rules.activitiesList.at(ai);
 				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					assert(act!=NULL);
 					s += act->subjectName+" "+act->subjectTagName+"\n"; //added in version 3_9_16, on 16 Oct. 2004; suggested by Nicholas Robinson
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
 						s += (*it) + " ";
 				}
 				ai=teachers_timetable_week2[teacher][k][j]; //activity index
-				act=gt.rules.activitiesList.at(ai);
-				if(ai!=UNALLOCATED_ACTIVITY && !act->studentsNames.isEmpty())
-					s += "/ ";
+				//act=gt.rules.activitiesList.at(ai);
+				//if(ai!=UNALLOCATED_ACTIVITY && !act->studentsNames.isEmpty())
+				//	s += "/ ";
 				if(ai!=UNALLOCATED_ACTIVITY){
+					Activity* act=&gt.rules.internalActivitiesList[ai];
 					assert(act!=NULL);
+					if(!act->studentsNames.isEmpty())
+						s+="/ ";
 					s += act->subjectName+" "+act->subjectTagName+"\n"; //added in version 3_9_16, on 16 Oct. 2004; suggested by Nicholas Robinson
 					for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
 						s += (*it) + " ";
@@ -145,19 +154,86 @@ void TimetableViewTeachersForm::detailActivity(int row, int col){
 		s = "";
 		if(j>=0 && k>=0){
 			int ai=teachers_timetable_week1[teacher][k][j]; //activity index
-			Activity* act=gt.rules.activitiesList.at(ai);
+			//Activity* act=gt.rules.activitiesList.at(ai);
 			if(ai!=UNALLOCATED_ACTIVITY){
+				Activity* act=&gt.rules.internalActivitiesList[ai];
 				assert(act!=NULL);
-				s += act->getDetailedDescription(gt.rules);
+				s += act->getDetailedDescriptionWithConstraints(gt.rules);
 			}
 			ai=teachers_timetable_week2[teacher][k][j]; //activity index
-			act=gt.rules.activitiesList.at(ai);
+			//act=gt.rules.activitiesList.at(ai);
 			if(ai!=UNALLOCATED_ACTIVITY){
+				Activity* act=&gt.rules.internalActivitiesList[ai];
 				assert(act!=NULL);
 				s += "/\n";
-				s += act->getDetailedDescription(gt.rules);
+				s += act->getDetailedDescriptionWithConstraints(gt.rules);
 			}
 		}
 		detailsTextEdit->setText(s);
 	}
 }
+
+void TimetableViewTeachersForm::lock()
+{
+	if(simulation_running){
+		QMessageBox::information(this, QObject::tr("FET information"),
+			QObject::tr("Allocation in course.\nPlease stop simulation before this."));
+		return;
+	}
+
+	//find teacher index
+	QString teachername;
+
+	if(teachersListBox->currentText()==NULL)
+		return;
+
+	teachername = teachersListBox->currentText();
+	int i=gt.rules.searchTeacher(teachername);
+
+	TimeChromosome* tc=&best_time_chromosome;
+
+	//lock selected activities
+	for(int j=0; j<gt.rules.nHoursPerDay; j++){
+		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
+			if(teachersTimetableTable->isSelected(j+1, k+1)){
+				int ai=teachers_timetable_week1[i][k][j];
+				if(ai!=UNALLOCATED_ACTIVITY){
+					int time=tc->times[ai];
+					int hour=time/gt.rules.nDaysPerWeek;
+					int day=time%gt.rules.nDaysPerWeek;
+					//Activity* act=gt.rules.activitiesList.at(ai);
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(1, true, act->id, day, hour);
+					bool t=gt.rules.addTimeConstraint(ctr);
+					if(t)
+						QMessageBox::information(this, QObject::tr("FET information"), 
+						 QObject::tr("Added the following constraint:\n"+ctr->getDetailedDescription(gt.rules)));
+					else{
+						QMessageBox::warning(this, QObject::tr("FET information"), 
+						 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
+						delete ctr;
+					}
+				}
+				
+				ai=teachers_timetable_week2[i][k][j];
+				if(ai!=UNALLOCATED_ACTIVITY){
+					int time=tc->times[ai];
+					int hour=time/gt.rules.nDaysPerWeek;
+					int day=time%gt.rules.nDaysPerWeek;
+					//Activity* act=gt.rules.activitiesList.at(ai);
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(1, true, act->id, day, hour);
+					bool t=gt.rules.addTimeConstraint(ctr);
+					if(t)
+						QMessageBox::information(this, QObject::tr("FET information"), 
+						 QObject::tr("Added the following constraint:\n"+ctr->getDetailedDescription(gt.rules)));
+					else{
+						QMessageBox::warning(this, QObject::tr("FET information"), 
+						 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
+						delete ctr;
+					}
+				}
+			}
+		}
+	}
+}
